/***************************************************************************
                               kmemconfig.h
                             -------------------
    begin                : Thu Jun 13 2002
    copyright            : (C) 2002 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMEMCONFIG_H
#define KMEMCONFIG_H

#include <kconfigbase.h>

#include <qmap.h>
#include <qstring.h>
#include <kapp.h>

/**
  *@author Kmud Developer Team
  */
class KMemConfig : public KConfigBase
{
public: 
	KMemConfig();
	~KMemConfig();

	/** This is used to print debug info contain all the keys and data in a group
      * @param group The group to print */
	void printDebugOutput(QString group);
	/** This method is used to copy a group to another group in another KMemConfig object
	  * @param The group to copy from
	  * @param newProp The KMemConfig group to copy to
      */
	void copyTo(QString fromGroup,KMemConfig *newProp);
	/**
	 * Returns a list of groups that are known.
	 */
	virtual QStringList groupList() const;

	/**
	 * Returns a map (tree) of entries for all entries in a particular
	 * group.
	 *
	 *  Only the actual entry string is returned, none of the
	 * other internal data should be included.
	 *
	 * @param pGroup A group to get keys from.
	 * @return A map of entries in the group specified, indexed by key.
	 *         The returned map may be empty if the group is not found.
	 */
	virtual QMap<QString, QString> entryMap(const QString &pGroup) const;

	/**
	 * Clears all internal data structures and then reread
	 * configuration information from disk.
	 */
	virtual void reparseConfiguration();

protected:

  /**
   * Returns true if the specified group is known.
   *
   * @param group The group to search for.
   * @returns @p true if the group exists.
   */
  virtual bool internalHasGroup(const QCString &group) const;

  /**
   * Returns a map (tree) of the entries in the specified group.
   *
   * Do not use this function, the implementation / return type are
   * subject to change.
   *
   * @param pGroup the group to provide a KEntryMap for.
   * @return The map of the entries in the group.
   * @internal
   */
  virtual KEntryMap internalEntryMap(const QString &pGroup) const;

  /**
   * Returns a copy of the internal map used to hold all entries.
   *
   * Do not use this function, the implementation / return type are
   * subject to change.
   *
   * @param pGroup the group to provide a KEntryMap for.
   * @return The map of the entries in the group.
   * @internal
   */
   virtual KEntryMap internalEntryMap() const { return aEntryMap; }

  /**
   * Inserts a (key, value) pair into the internal storage mechanism of
   * the configuration object.
   *
   * @param _key The key to insert.  It contains information both on
   *        the group of the key and the key itself. If the key already
   *        exists, the old value will be replaced.
   * @param _data the KEntry that is to be stored.
   * @param _checkGroup When false, assume that the group already exists.
   */
  virtual void putData(const KEntryKey &_key, const KEntry &_data, bool _checkGroup=true);

  /**
   * Looks up an entry in the config object's internal structure.
   *
   * @param _key The key to look up  It contains information both on
   *        the group of the key and the entry's key itself.
   * @return the KEntry value (data) found for the key.  KEntry.aValue
   * will be the null string if nothing was located.
   */
  virtual KEntry lookupData(const KEntryKey &_key) const;

private:
	/**
   * Contains all key,value entries, as well as some "special"
   * keys which indicate the start of a group of entries.
   *
   * These special keys will have the .key portion of their @ref KEntryKey
   * set to QString::null.
   */
  KEntryMap aEntryMap;
};

#endif
