/***************************************************************************
                               kmudsetuppane.h
                             -------------------
    begin                : Wed Jun 26 2002
    copyright            : (C) 2002 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMUDSETUPPANE_H
#define KMUDSETUPPANE_H

#include <qstring.h>
#include <qwidget.h>

/**This is the base class for all setup panes
  *@author Kmud Developer Team
  */

class KmudSetupPane : public QWidget
{
	Q_OBJECT
public:
	enum PaneType { PROFILE=0, KMUD=1, GLOBAL=2 };


	/**
	 * The constructor used to create the pane of a given type
	 * @param type The type of settings this pane will alter
	 * @param group The group the main is to be inserted into.
	 *              If Empty then it will be inserted at the top level of the tree.
	 *              If it contained "Mapper/Colors" then it would be under Mapper
	 *              item, then a Colors Item.
	 * @param parent The parent widget
	 * @param name The name of the pane. This name is displayed in the config tree
	 */
	KmudSetupPane(PaneType type,QString group,QWidget *parent,const char *name);
	virtual ~KmudSetupPane();

	/** This is used to get the pane type
	  * @return The type of pane */
	KmudSetupPane::PaneType getPaneType();
	/** This is used to get the group that the pane belongs to */
	QString getGroup(void);
	
public slots:
	/** This slot is called when the delfault/reset button is pressed */
	virtual void slotDefaultPressed()=0;
	/** This slot is called when the cancel button is pressed */
	virtual void slotCancelPressed()=0;
	/** This slot is called when the OK button is pressed */
	virtual void slotOkPressed()=0;

protected:
	/** This is used to add the base dialog class to the setup pane */
	void addBaseDialog(QWidget *widget);
	/** This is used to get the base dialog pointer, this is for accessing
 	  * the components of the dialog */
	QWidget *getBaseDialog(void);

private:
	/** This is used to store the panes group */
	QString m_group;
	/** This is used to store the type of pane */
	PaneType m_type;
	/** A pointer to the base dialog with all the components */
	QWidget *m_baseDlg;

};

#endif
